==> apache-camel-quarkus-3.8.2-src.zip: camel-quarkus-3.8.2/extensions/jasypt/runtime/src/main/java/org/apache/camel/quarkus/component/jasypt/CamelJasyptRecorder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.jasypt;

import io.quarkus.runtime.RuntimeValue;
import io.quarkus.runtime.annotations.Recorder;
import org.apache.camel.CamelContext;
import org.apache.camel.component.jasypt.JasyptPropertiesParser;
import org.apache.camel.component.properties.PropertiesComponent;
import org.apache.camel.main.MainConfigurationProperties;
import org.apache.camel.quarkus.main.CamelMain;
import org.apache.camel.spi.CamelContextCustomizer;

@Recorder
public class CamelJasyptRecorder {
    public void disableCamelMainAutoConfigFromSysEnv(RuntimeValue<CamelMain> camelMainRuntimeValue, CamelJasyptConfig config) {
        CamelMain main = camelMainRuntimeValue.getValue();
        MainConfigurationProperties configurationProperties = main.getMainConfigurationProperties();
        configurationProperties.setAutoConfigurationSystemPropertiesEnabled(false);
        configurationProperties.setAutoConfigurationEnvironmentVariablesEnabled(false);
    }

    public RuntimeValue<CamelContextCustomizer> createPropertiesComponentCamelContextCustomizer(
            CamelJasyptBuildTimeConfig config) {
        return new RuntimeValue<>(new CamelContextCustomizer() {
            @Override
            public void configure(CamelContext camelContext) {
                if (config.enabled) {
                    PropertiesComponent component = (PropertiesComponent) camelContext.getPropertiesComponent();
                    JasyptPropertiesParser jasyptPropertiesParser = CamelJasyptPropertiesParserHolder
                            .getJasyptPropertiesParser();
                    jasyptPropertiesParser.setPropertiesComponent(component);
                    component.setPropertiesParser(jasyptPropertiesParser);
                }
            }
        });
    }
}

==> apache-camel-quarkus-3.15.4-src.zip: camel-quarkus-3.15.4/extensions/jasypt/runtime/src/main/java/org/apache/camel/quarkus/component/jasypt/CamelJasyptRecorder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.jasypt;

import io.quarkus.runtime.RuntimeValue;
import io.quarkus.runtime.annotations.Recorder;
import org.apache.camel.CamelContext;
import org.apache.camel.component.jasypt.JasyptPropertiesParser;
import org.apache.camel.component.properties.PropertiesComponent;
import org.apache.camel.main.MainConfigurationProperties;
import org.apache.camel.quarkus.main.CamelMain;
import org.apache.camel.spi.CamelContextCustomizer;

@Recorder
public class CamelJasyptRecorder {
    public void disableCamelMainAutoConfigFromSysEnv(RuntimeValue<CamelMain> camelMainRuntimeValue) {
        CamelMain main = camelMainRuntimeValue.getValue();
        MainConfigurationProperties configurationProperties = main.getMainConfigurationProperties();
        configurationProperties.setAutoConfigurationSystemPropertiesEnabled(false);
        configurationProperties.setAutoConfigurationEnvironmentVariablesEnabled(false);
    }

    public RuntimeValue<CamelContextCustomizer> createPropertiesComponentCamelContextCustomizer() {
        return new RuntimeValue<>(new CamelContextCustomizer() {
            @Override
            public void configure(CamelContext camelContext) {
                PropertiesComponent component = (PropertiesComponent) camelContext.getPropertiesComponent();
                JasyptPropertiesParser jasyptPropertiesParser = CamelJasyptPropertiesParserHolder
                        .getJasyptPropertiesParser();
                jasyptPropertiesParser.setPropertiesComponent(component);
                component.setPropertiesParser(jasyptPropertiesParser);
            }
        });
    }
}
